Installation — django-campaign 0.3.0-pre documentation

### Navigation

- index
- next |
- previous |
- django-campaign 0.3.0-pre documentation »

# Installation

Install django-campaign with `easy_install` or `pip` or directly from the GitHub repository.

Then add `campaign` and ‘django.contrib.sites’ to your `INSTALLED_APPS` setting:

    INSTALLED_APPS = (
        ...
        'django.contrib.sites',
        'campaign',
        ...
    )

Add an entry to your URL-conf. Using `campaign` here is a matter of taste, feel free to mount the app under a different URL:

    urlpatterns += patterns('',
        (r'^campaign/', include('campaign.urls'))
    )

4. Then run `manage.py syncdb` to create the neccessary database tables.

### Navigation

- index
- next |
- previous |
- django-campaign 0.3.0-pre documentation »